@@ -1,9 +1,9 @@
 # -*- coding: utf-8 -*-
 
-from core import *
 from ogg import VorbisEncoder
 from wav import WavEncoder
 from mp3 import Mp3Encoder
 from flac import FlacEncoder
 from m4a import AacEncoder
 from webm import WebMEncoder
+from audiosink import AudioSink
\ No newline at end of file
