@@ -93,7 +93,5 @@ class WebMEncoder(GstEncoder):
         self.metadata = metadata
 
 if __name__ == "__main__":
-    # Run doctest from __main__ and unittest from test_analyzer_preprocessors
-    from tests import test_encoding, test_transcoding
-    from tests.unit_timeside import run_test_module
-    run_test_module([test_encoding, test_transcoding], test_prefix='testWebM')
\ No newline at end of file
+    import doctest
+    doctest.testmod()
